@@ -11,7 +11,7 @@ pub enum ParseError {
 impl Display for ParseError {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
-            Self::MissingEndTag(name) => write!(f, "missing end tag: `{}`", name),
+            Self::MissingEndTag(name) => write!(f, "missing end tag: `{name}`"),
         }
     }
 }
